@@ -66,9 +66,9 @@ double diff_logprior = 0;
 
 // stuff for likelihood handling and computations
 double diff_loglikelihood = 0;
-double *current_ll_node;
-double alpha_data = 1.5;    // prior Gamma shape for data precision
-double beta_data  = 1000;   // prior Gamma rate for data precision
+double *current_ll_node = NULL;
+double alpha_data    = 1.5;    // prior Gamma shape for data precision
+double beta_data     = 1000;   // prior Gamma rate for data precision
 
 // stuff for posterior handling
 double diff_logposterior = 0;
@@ -119,7 +119,6 @@ void CleanupMemory (void)
      graph_sampler [input-file [output-files prefix]]
 
    Missing names are replaced by defaults .
-
 */
 void GetCmdLineArgs (int cArg, char *const *rgszArg, char **pszFileIn, 
                      char **pszPrefixOut)
@@ -394,13 +393,16 @@ void Loglikelihood_diff (int parent, int child, int diff,
      N : number of nodes
      adjacency : a pointer to the adjacency matrix
      pData : a data structure
+   The adjacency matrix on which it operates is global and actually not
+   used here, but below (in the individual nodes likelihood calculations).
 */
-double Loglikelihood_full (int N, int **adjacency, double **pData)
+double Loglikelihood_full (int N, double **pData)
 {
   double cumLL = 0;
   int    i;
 
-  current_ll_node = InitdVector(N);
+  if (!current_ll_node) 
+    current_ll_node = InitdVector(N);
 
   // sum up the log-likelihoods of each node
   for (i = 0; i < N; i++) {
@@ -724,7 +726,8 @@ double DLoglikelihood_node (int node, double **pData)
     pData: data array
     
    Computation proceeds by forming
-   mx = Y' * Y - n/(n + 1) * (Y' * X) * inv((X' * X)) * (X' * Y)
+   mx = Y' * Y - g_z/(g_z + 1) * (Y' * X) * inv((X' * X)) * (X' * Y)
+   where g_z is a tuning parameter
    and then
    Loglikelihood = -(eta + 1)/2 * log(1 + n) - n/2 * log(mx)
    were Y are the data for the node considered and X the design matrix
@@ -817,7 +820,7 @@ double ZLoglikelihood_node (int node, double **pData)
   }
 
   // finish mx as mx + pdV2 * t(pdV1) 
-  mx = mx - nData / ((double) nData + 1) * pdV2[0];
+  mx = mx - gamma_zellner / (gamma_zellner + 1) * pdV2[0];
   
   LL = 0.5 * (-nParents[node] - 1) * log(1 + nData) - 0.5 * nData * log(mx);
 
@@ -839,7 +842,6 @@ double ZLoglikelihood_node (int node, double **pData)
      +1: creation
    Outputs:
     *logPdiff: total CHANGE in prior log-density.
-
 */
 void Logprior_diff (int **adjacency_current, int parent_node, int child_node,
                     int diff, double *logPdiff)
@@ -1038,6 +1040,7 @@ void ReadScript_Bison (char *const filename)
   // set non-zero default values for scalar predefined variables here
   lambda_concord = 1;
   gamma_degree   = 1;
+  gamma_zellner  = 1;
   alpha_motif    = 1;
   beta_motif     = 1;
   iter           = 1000000000;
@@ -1130,7 +1133,6 @@ void SetPriorHyperParam (void)
    UndoDiff
    
    Undoes the change in global number of parents of node "child".
-   
 */
 void UndoDiff (int parent, int child, int diff)
 {
@@ -1215,7 +1217,7 @@ int main (int nArgs, char *const *rgszArg)
 
   if (bBN && bData) {
     // SetPriorHyperParam(); disabled
-    current_loglikelihood = Loglikelihood_full(nNodes, current_adj, pData);
+    current_loglikelihood = Loglikelihood_full(nNodes, pData);
   }
   else 
     current_loglikelihood = 0;
